Simple Test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/vl6180x_simpletest.py
    :caption: examples/vl6180x_simpletest.py
    :linenos:


Calibration Test
-----------------

Demo of calibrating the part to part range offset per Application Note 4545 for the VL6180X sensor.

.. literalinclude:: ../examples/vl6180x_calibrationtest.py
    :caption: examples/vl6180x_calibrationtest.py
    :linenos:


Continuous Test
----------------

Demo of reading the range from the VL6180x distance sensor in continuous mode.

.. literalinclude:: ../examples/vl6180x_continuoustest.py
    :caption: examples/vl6180x_continuoustest.py
    :linenos:


History Test
-------------

Demo of reading the range from the history buffer of the VL6180x distance sensor.

.. literalinclude:: ../examples/vl6180x_historytest.py
    :caption: examples/vl6180x_historytest.py
    :linenos:


Performance Test
-----------------

Demo of reading the range from the VL6180x distance sensor in different access modes (single shot, continuous, history).

.. literalinclude:: ../examples/vl6180x_performancetest.py
    :caption: examples/vl6180x_performancetest.py
    :linenos:
